@@ -5,17 +5,18 @@ Copyright 2010 Canonical Ltd.
 
 Authors:
     Ted Gould <ted@canonical.com>
+    Conor Curran <conor.curran@canonical.com>
 
-This program is free software: you can redistribute it and/or modify it 
-under the terms of the GNU General Public License version 3, as published 
+This program is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License version 3, as published
 by the Free Software Foundation.
 
-This program is distributed in the hope that it will be useful, but 
-WITHOUT ANY WARRANTY; without even the implied warranties of 
-MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranties of
+MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License along 
+You should have received a copy of the GNU General Public License along
 with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
@@ -26,9 +27,9 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <gio/gio.h>
 
 #include "session-dbus.h"
-#include "dbus-shared-names.h"
+#include "shared-names.h"
 
-static GVariant * get_icon (SessionDbus * service);
+static GVariant * get_users_real_name (SessionDbus * service);
 static void bus_get_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 static void bus_method_call (GDBusConnection * connection, const gchar * sender, const gchar * path, const gchar * interface, const gchar * method, GVariant * params, GDBusMethodInvocation * invocation, gpointer user_data);
 
@@ -98,7 +99,7 @@ session_dbus_init (SessionDbus *self)
 {
 	SessionDbusPrivate * priv = SESSION_DBUS_GET_PRIVATE(self);
 
-	priv->name = g_strdup(ICON_DEFAULT);
+	priv->name = NULL;
 	priv->bus = NULL;
 	priv->bus_cancel = NULL;
 	priv->dbus_registration = 0;
@@ -160,15 +161,16 @@ bus_method_call (GDBusConnection * connection, const gchar * sender,
                  const gchar * method, GVariant * params,
                  GDBusMethodInvocation * invocation, gpointer user_data)
 {
-	SessionDbus * service = SESSION_DBUS(user_data);
+	SessionDbus * service = SESSION_DBUS (user_data);
+
 	GVariant * retval = NULL;
 
-	if (g_strcmp0(method, "GetIcon") == 0) {
-		retval = get_icon(service);
-	} else {
-		g_warning("Calling method '%s' on the indicator service and it's unknown", method);
+	if (g_strcmp0(method, "GetUserRealName") == 0) {
+		retval = get_users_real_name (service);
+	}
+  else {
+    g_warning("Calling method '%s' on the indicator service and it's unknown", method);
 	}
-
 	g_dbus_method_invocation_return_value(invocation, retval);
 	return;
 }
@@ -204,20 +206,17 @@ session_dbus_finalize (GObject *object)
 {
 	SessionDbusPrivate * priv = SESSION_DBUS_GET_PRIVATE(object);
 
-	if (priv->name != NULL) {
-		g_free(priv->name);
-		priv->name = NULL;
-	}
+	g_clear_pointer (&priv->name, g_free);
 
 	G_OBJECT_CLASS (session_dbus_parent_class)->finalize (object);
 	return;
 }
 
 static GVariant *
-get_icon (SessionDbus * service)
+get_users_real_name (SessionDbus * service)
 {
 	SessionDbusPrivate * priv = SESSION_DBUS_GET_PRIVATE(service);
-	return g_variant_new("(s)", priv->name);
+	return g_variant_new ("(s)", priv->name ? priv->name : "");
 }
 
 SessionDbus *
@@ -228,30 +227,56 @@ session_dbus_new (void)
 
 void
 session_dbus_set_name (SessionDbus * session, const gchar * name)
+{
+}
+
+void
+session_dbus_set_users_real_name (SessionDbus * session, const gchar * name)
 {
 	SessionDbusPrivate * priv = SESSION_DBUS_GET_PRIVATE(session);
 	GError * error = NULL;
-	if (priv->name != NULL) {
-		g_free(priv->name);
-		priv->name = NULL;
-	}
+
+	g_free (priv->name);
 	priv->name = g_strdup(name);
 
 	if (priv->bus != NULL) {
 		g_dbus_connection_emit_signal (priv->bus,
-			                       NULL,
-			                       INDICATOR_SESSION_SERVICE_DBUS_OBJECT,
-			                       INDICATOR_SESSION_SERVICE_DBUS_IFACE,
-			                       "IconUpdated",
-			                       g_variant_new ("(s)", priv->name, NULL),
-			                       &error);
+                                   NULL,
+                                   INDICATOR_SESSION_SERVICE_DBUS_OBJECT,
+                                   INDICATOR_SESSION_SERVICE_DBUS_IFACE,
+                                   "UserRealNameUpdated",
+                                   g_variant_new ("(s)", priv->name, NULL),
+                                   &error);
 
 		if (error != NULL) {
-			g_warning("Unable to send IconUpdated signal: %s", error->message);
+			g_warning("Unable to send UserRealNameUpdated signal: %s", error->message);
 			g_error_free(error);
 			return;
 		}
 	}
-
 	return;
 }
+
+void session_dbus_restart_required (SessionDbus* session)
+{
+	SessionDbusPrivate * priv = SESSION_DBUS_GET_PRIVATE(session);
+	GError * error = NULL;
+
+	if (priv->bus != NULL) {
+    g_debug("About to send RebootRequired signal");
+
+		g_dbus_connection_emit_signal (priv->bus,
+                                   NULL,
+                                   INDICATOR_SESSION_SERVICE_DBUS_OBJECT,
+                                   INDICATOR_SESSION_SERVICE_DBUS_IFACE,
+                                   "RestartRequired",
+                                   NULL,
+                                   &error);
+
+		if (error != NULL) {
+			g_warning("Unable to send reboot-required signal: %s", error->message);
+			g_error_free(error);
+		}
+	}
+
+}
